@@ -35,6 +35,7 @@ JSON_API = 'http://%s/API/jsonI.php' % IP
 DATA_TYPES = ['uint16', 'hex16']
 MAX_LEN = 100
 
+
 def get_data(data_type='uint16', array_length=1, block_size=1):
     """Fetch data from the ANU Quantum Random Numbers JSON API"""
     if data_type not in DATA_TYPES:
@@ -46,7 +47,17 @@ def get_data(data_type='uint16', array_length=1, block_size=1):
         'length': array_length,
         'size': block_size,
         })
-    data = json.loads(urllib2.urlopen(req).read())
+    data = json.loads(urllib2.urlopen(req).read(), object_hook=_object_hook)
     assert data['success'] is True, data
     assert data['length'] == array_length, data
     return data['data']
+
+
+def _object_hook(obj):
+    """We are only dealing with ASCII characters"""
+    if obj['type'] == 'string':
+        obj['data'] = [s.encode('ascii') for s in obj['data']]
+    return obj
+
+
+__all__ = ['get_data']
